Module value
es_
htmlform
0.1.1
Module value
Module Items
Structs
Functions
In crate es_
htmlform
es_htmlform
Module
value
Structs

UrlDecoding
Error
Error to denote
urldecode()
fails.
Value
A single form value, stored as
String
. May be empty in some cases, which results in the value being ignored in validation.
Value
Map
A set of form values. Note that values are always stored as lists of strings, similar to how urlencoded form data is treated (no type information, any field may appear more than once and there doesn’t need to be a value).
Functions

urldecode
Decode url-encoded bytes to a UTF-8
String
.