[−][src]Struct es_htmlform::value::Value
A single form value, stored as String. May be empty in some cases,
which results in the value being ignored in validation.
Methods
impl Value[src]
pub fn new(value: &str) -> Value[src]
pub fn as_string(&self) -> String[src]
pub fn parse<T>(&self) -> Result<T, ValidationError> where
T: FromStr, [src]
T: FromStr,
Methods from Deref<Target = String>
pub fn as_str(&self) -> &str1.7.0[src]
Extracts a string slice containing the entire String.
Examples
Basic usage:
let s = String::from("foo"); assert_eq!("foo", s.as_str());
pub fn capacity(&self) -> usize1.0.0[src]
Returns this String's capacity, in bytes.
Examples
Basic usage:
let s = String::with_capacity(10); assert!(s.capacity() >= 10);
pub fn as_bytes(&self) -> &[u8]1.0.0[src]
Returns a byte slice of this String's contents.
The inverse of this method is from_utf8.
Examples
Basic usage:
let s = String::from("hello"); assert_eq!(&[104, 101, 108, 108, 111], s.as_bytes());
pub fn len(&self) -> usize1.0.0[src]
Returns the length of this String, in bytes.
Examples
Basic usage:
let a = String::from("foo"); assert_eq!(a.len(), 3);
pub fn is_empty(&self) -> bool1.0.0[src]
Returns true if this String has a length of zero, and false otherwise.
Examples
Basic usage:
let mut v = String::new(); assert!(v.is_empty()); v.push('a'); assert!(!v.is_empty());