[−][src]Enum es_htmlform::types::Attr
An HTML attribute without validation behaviour. The list should be
complete and up-to-date with the latest HTML specifications. HTML
validity is checked when adding the attributes to the fields using
HtmlForm's builder methods.
Variants
Use to add any attribute to any element without validation.
Id(&'a str)Title(&'a str)Placeholder(&'a str)Autocomplete(Autocomplete)Tabindex(i64)StepFloat(f64)StepInt(u64)Size(u64)Width(u64)Height(u64)Rows(u64)Cols(u64)Spellcheck(Spellcheck)Wrap(Wrap)FormAction(&'a str)FormEnctype(&'a str)FormTarget(&'a str)Methods
impl<'a> Attr<'a>[src]
pub fn attrpair(&self) -> (String, String)[src]
pub fn allowed_on(&self, element: &Element) -> bool[src]