[−][src]Module es_htmlform::value
Structs
| UrlDecodingError | Error to denote |
| Value | A single form value, stored as |
| ValueMap | A set of form values. Note that values are always stored as lists of strings, similar to how urlencoded form data is treated (no type information, any field may appear more than once and there doesn't need to be a value). |
Functions
| urldecode | Decode url-encoded bytes to a UTF-8 |